axsdb
=====

.. rubric:: Modules:

.. toctree::
    :maxdepth: 2
    :hidden:

    axsdb.interpolation
    axsdb.math
    axsdb.units

.. autosummary::

    axsdb.interpolation
    axsdb.math
    axsdb.units

.. automodule:: axsdb
    :autosummary:
    :members:
    :show-inheritance:
    :inherited-members:
